pub struct DataSinkHB {
pub met: u64,
pub n_packets_sent: u64,
pub n_packets_incoming: u64,
pub n_bytes_written: u64,
pub n_evid_missing: u64,
pub n_evid_chunksize: u64,
pub evid_missing: u64,
pub evid_check_len: u64,
pub n_pack_write_disk: u64,
pub incoming_ch_len: u64,
pub timestamp: u64,
}Fields
met: u64mission elapsed time in seconds
n_packets_sent: u64n_packets_incoming: u64n_bytes_written: u64bytes written to disk
n_evid_missing: u64event id check - missing event ids
n_evid_chunksize: u64event id check - chunksize
evid_missing: u64length of incoming buffer for the thread check for missing event ids
evid_check_len: u64probe size for missing event id check
n_pack_write_disk: u64number of packets written to disk
incoming_ch_len: u64length of the incoming channel, which is basically packets queued to be sent
timestamp: u64Implementations
Sourceimpl DataSinkHB
impl DataSinkHB
pub fn new() -> Self
pub fn get_sent_packet_rate(&self) -> f64
pub fn get_mbytes_to_disk_per_sec(&self) -> f64